/*
 * IPSec Passthrough Modifier: Chad Sheu, CharlesTU
 * Reference: kernel 2.6.20.15
 */   
#ifndef _CONNTRACK_PROTO_ESP_H
#define _CONNTRACK_PROTO_ESP_H
#include <asm/byteorder.h>
#include <linux/timer.h>
#include <linux/list.h>
#include <linux/ip.h>
/* ESP PROTOCOL HEADER */

/* ESP Variate field */
#define ESP_PROTOCOL	(0x32)

/* Compatibility definitions for ipt_FOO modules */
#define	IP_NF_ASSERT			NF_CT_ASSERT

/* ESP is a mess*/
struct esp_hdr {
	__u32	spi;
	__u32	seq;
};

/* this is part of ip_conntrack */
struct nf_ct_esp {
	unsigned int stream_timeout;
	unsigned int timeout;
};

/* this is part of ip_conntrack_expect */
struct nf_ct_esp_expect {
	struct nf_ct_esp_spi *spi_orig, *spi_reply;
};

#ifdef __KERNEL__
struct nf_conntrack_expect;

/* conntrack private data */
struct nf_ct_esp_master {
	unsigned int sip;
	unsigned int dip;
	unsigned int spi_local;
	unsigned int spi_remote;
	unsigned int dir;
};

/* structure for original ip <-> reply spi to find correct ip */
struct nf_ct_esp_spi {
	struct list_head list;
	struct timer_list timeout;	/* Timer for list destroying */
    struct nf_ct_esp_master esp_master;
};

unsigned int esp_packet_in(const struct iphdr *iph, u_int32_t *sip, u_int32_t *dip);
unsigned int esp_packet_out(const struct iphdr *iph, unsigned int len, enum ip_conntrack_info ctinfo);


/* add new tuple->key_reply pair to keymap */
int nf_ct_esp_spi_add(struct nf_conntrack_expect *exp, struct nf_conntrack_tuple *t, int reply);

/* change an existing keymap entry */
void nf_ct_esp_spi_change(struct nf_ct_esp_spi *spi, struct nf_conntrack_tuple *t);

/* delete keymap entries */
void nf_ct_esp_spi_destroy(struct nf_conntrack_expect *exp);


#endif /* __KERNEL__ */

#endif /* _CONNTRACK_PROTO_ESP_*/



